==> chaosmesh-model-6.0.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodNetworkChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodNetworkChaosFluentImpl<A extends PodNetworkChaosFluent<A>> extends BaseFluent<A> implements PodNetworkChaosFluent<A>{
  public PodNetworkChaosFluentImpl() {
  }
  public PodNetworkChaosFluentImpl(PodNetworkChaos instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private PodNetworkChaosSpecBuilder spec;
  private PodNetworkChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public PodNetworkChaosFluent.MetadataNested<A> withNewMetadata() {
    return new PodNetworkChaosFluentImpl.MetadataNestedImpl();
  }
  public PodNetworkChaosFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new PodNetworkChaosFluentImpl.MetadataNestedImpl(item);
  }
  public PodNetworkChaosFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public PodNetworkChaosFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public PodNetworkChaosFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodNetworkChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public PodNetworkChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(PodNetworkChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new PodNetworkChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public PodNetworkChaosFluent.SpecNested<A> withNewSpec() {
    return new PodNetworkChaosFluentImpl.SpecNestedImpl();
  }
  public PodNetworkChaosFluent.SpecNested<A> withNewSpecLike(PodNetworkChaosSpec item) {
    return new PodNetworkChaosFluentImpl.SpecNestedImpl(item);
  }
  public PodNetworkChaosFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public PodNetworkChaosFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new PodNetworkChaosSpecBuilder().build());
  }
  public PodNetworkChaosFluent.SpecNested<A> editOrNewSpecLike(PodNetworkChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodNetworkChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public PodNetworkChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(PodNetworkChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new PodNetworkChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public PodNetworkChaosFluent.StatusNested<A> withNewStatus() {
    return new PodNetworkChaosFluentImpl.StatusNestedImpl();
  }
  public PodNetworkChaosFluent.StatusNested<A> withNewStatusLike(PodNetworkChaosStatus item) {
    return new PodNetworkChaosFluentImpl.StatusNestedImpl(item);
  }
  public PodNetworkChaosFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public PodNetworkChaosFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new PodNetworkChaosStatusBuilder().build());
  }
  public PodNetworkChaosFluent.StatusNested<A> editOrNewStatusLike(PodNetworkChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodNetworkChaosFluentImpl that = (PodNetworkChaosFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<PodNetworkChaosFluent.MetadataNested<N>> implements PodNetworkChaosFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) PodNetworkChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends PodNetworkChaosSpecFluentImpl<PodNetworkChaosFluent.SpecNested<N>> implements PodNetworkChaosFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(PodNetworkChaosSpec item) {
      this.builder = new PodNetworkChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new PodNetworkChaosSpecBuilder(this);
    }
    PodNetworkChaosSpecBuilder builder;
    public N and() {
      return (N) PodNetworkChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends PodNetworkChaosStatusFluentImpl<PodNetworkChaosFluent.StatusNested<N>> implements PodNetworkChaosFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(PodNetworkChaosStatus item) {
      this.builder = new PodNetworkChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new PodNetworkChaosStatusBuilder(this);
    }
    PodNetworkChaosStatusBuilder builder;
    public N and() {
      return (N) PodNetworkChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> chaosmesh-model-6.5.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodNetworkChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Long;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodNetworkChaosFluentImpl<A extends PodNetworkChaosFluent<A>> extends BaseFluent<A> implements PodNetworkChaosFluent<A>{
  public PodNetworkChaosFluentImpl() {
  }
  public PodNetworkChaosFluentImpl(PodNetworkChaos instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private PodNetworkChaosSpecBuilder spec;
  private PodNetworkChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public PodNetworkChaosFluent.MetadataNested<A> withNewMetadata() {
    return new PodNetworkChaosFluentImpl.MetadataNestedImpl();
  }
  public PodNetworkChaosFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new PodNetworkChaosFluentImpl.MetadataNestedImpl(item);
  }
  public PodNetworkChaosFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public PodNetworkChaosFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public PodNetworkChaosFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodNetworkChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public PodNetworkChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(PodNetworkChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new PodNetworkChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public PodNetworkChaosFluent.SpecNested<A> withNewSpec() {
    return new PodNetworkChaosFluentImpl.SpecNestedImpl();
  }
  public PodNetworkChaosFluent.SpecNested<A> withNewSpecLike(PodNetworkChaosSpec item) {
    return new PodNetworkChaosFluentImpl.SpecNestedImpl(item);
  }
  public PodNetworkChaosFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public PodNetworkChaosFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new PodNetworkChaosSpecBuilder().build());
  }
  public PodNetworkChaosFluent.SpecNested<A> editOrNewSpecLike(PodNetworkChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodNetworkChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public PodNetworkChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(PodNetworkChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new PodNetworkChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public A withNewStatus(String failedMessage,Long observedGeneration) {
    return (A)withStatus(new PodNetworkChaosStatus(failedMessage, observedGeneration));
  }
  public PodNetworkChaosFluent.StatusNested<A> withNewStatus() {
    return new PodNetworkChaosFluentImpl.StatusNestedImpl();
  }
  public PodNetworkChaosFluent.StatusNested<A> withNewStatusLike(PodNetworkChaosStatus item) {
    return new PodNetworkChaosFluentImpl.StatusNestedImpl(item);
  }
  public PodNetworkChaosFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public PodNetworkChaosFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new PodNetworkChaosStatusBuilder().build());
  }
  public PodNetworkChaosFluent.StatusNested<A> editOrNewStatusLike(PodNetworkChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodNetworkChaosFluentImpl that = (PodNetworkChaosFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<PodNetworkChaosFluent.MetadataNested<N>> implements PodNetworkChaosFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) PodNetworkChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends PodNetworkChaosSpecFluentImpl<PodNetworkChaosFluent.SpecNested<N>> implements PodNetworkChaosFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(PodNetworkChaosSpec item) {
      this.builder = new PodNetworkChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new PodNetworkChaosSpecBuilder(this);
    }
    PodNetworkChaosSpecBuilder builder;
    public N and() {
      return (N) PodNetworkChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends PodNetworkChaosStatusFluentImpl<PodNetworkChaosFluent.StatusNested<N>> implements PodNetworkChaosFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(PodNetworkChaosStatus item) {
      this.builder = new PodNetworkChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new PodNetworkChaosStatusBuilder(this);
    }
    PodNetworkChaosStatusBuilder builder;
    public N and() {
      return (N) PodNetworkChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
